@@ -1,3 +1,4 @@
+from copy import deepcopy
 from django.contrib import admin
 from django.contrib.admin.options import csrf_protect_m
 
@@ -14,9 +15,10 @@ class DjangoTabbedChangeformAdmin(admin.ModelAdmin):
             ]
         }
         js = [
-            "jquery3/jquery.js",
+            "admin/js/vendor/jquery/jquery.js",
             "jquery-ui/jquery-ui.min.js",
             "django-tabbed-changeform-admin/js/django-tabbed-changeform-admin.js",
+            "admin/js/jquery.init.js",
         ]
 
     @csrf_protect_m
@@ -26,4 +28,4 @@ class DjangoTabbedChangeformAdmin(admin.ModelAdmin):
         return super().changeform_view(request, object_id, form_url, extra_context)
 
     def get_tabs(self, request, object_id, form_url, extra_context):
-        return self.tabs
+        return deepcopy(self.tabs)
